
PyFBA Documentation
===================

.. automodule:: PyFBA

The metabolism data
-------------------

Classes for handling the data

.. toctree::
   :maxdepth: 2
   
   enzyme.rst
   reaction.rst
   compound.rst
 
The FBA modules
---------------

Code for generating the stoichiometric matrix and running the FBA

.. toctree::
   :maxdepth: 2
   
   fba.rst

Filters for manipulating data
-----------------------------

Converting between reactions and roles, identifying roles with no proteins, etc

.. toctree::
   :maxdepth: 2

   filters.rst

Gapfilling
----------

.. toctree::
   :maxdepth: 2

   gapfilling.rst

The parsing modules
-------------------

Parsing data from different sources

.. toctree::
   :maxdepth: 2

   parse.rst 


